==> amzn-login-with-amazon-module-1.1.1.zip: Model/Customer/Account/Redirect.php <==
<?php
/**
 * Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
namespace Amazon\Login\Model\Customer\Account;

use Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Customer\Model\Account\Redirect as BaseRedirect;
use Magento\Customer\Model\Session as CustomerSession;
use Magento\Customer\Model\Url as CustomerUrl;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Url\DecoderInterface;
use Magento\Framework\UrlInterface;
use Magento\Store\Model\StoreManagerInterface;

class Redirect extends BaseRedirect
{
    /**
     * @var CheckoutSession
     */
    protected $checkoutSession;

    /**
     * @var CustomerSession
     */
    protected $customerSession;

    public function __construct(
        RequestInterface $request,
        CustomerSession $customerSession,
        ScopeConfigInterface $scopeConfig,
        StoreManagerInterface $storeManager,
        UrlInterface $url,
        DecoderInterface $urlDecoder,
        CustomerUrl $customerUrl,
        ResultFactory $resultFactory,
        CheckoutSession $checkoutSession
    ) {
        parent::__construct(
            $request,
            $customerSession,
            $scopeConfig,
            $storeManager,
            $url,
            $urlDecoder,
            $customerUrl,
            $resultFactory
        );

        $this->customerSession = $customerSession;
        $this->checkoutSession = $checkoutSession;
    }

    public function getRedirect()
    {
        $this->updateLastCustomerId();

        $result = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);

        $afterAmazonAuthUrl = $this->customerUrl->getAccountUrl();

        if ($this->customerSession->getAfterAmazonAuthUrl()) {
            $afterAmazonAuthUrl = $this->customerSession->getAfterAmazonAuthUrl();
        } elseif ($this->checkoutSession->getQuote() && (int)$this->checkoutSession->getQuote()->getItemsCount() > 0) {
            $afterAmazonAuthUrl = $this->url->getUrl('checkout');
        }

        $result->setUrl($afterAmazonAuthUrl);

        return $result;
    }
}

==> amzn-login-with-amazon-module-1.1.4.zip: Model/Customer/Account/Redirect.php <==
<?php
/**
 * Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
namespace Amazon\Login\Model\Customer\Account;

use Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Customer\Model\Account\Redirect as BaseRedirect;
use Magento\Customer\Model\Session as CustomerSession;
use Magento\Customer\Model\Url as CustomerUrl;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\RequestInterface;
use Magento\Framework\Controller\ResultFactory;
use Magento\Framework\Url\DecoderInterface;
use Magento\Framework\UrlInterface;
use Magento\Store\Model\StoreManagerInterface;

class Redirect extends BaseRedirect
{
    /**
     * @var CheckoutSession
     */
    protected $checkoutSession;

    /**
     * @var CustomerSession
     */
    protected $customerSession;

    public function __construct(
        RequestInterface $request,
        CustomerSession $customerSession,
        ScopeConfigInterface $scopeConfig,
        StoreManagerInterface $storeManager,
        UrlInterface $url,
        DecoderInterface $urlDecoder,
        CustomerUrl $customerUrl,
        ResultFactory $resultFactory,
        CheckoutSession $checkoutSession
    ) {
        parent::__construct(
            $request,
            $customerSession,
            $scopeConfig,
            $storeManager,
            $url,
            $urlDecoder,
            $customerUrl,
            $resultFactory
        );

        $this->customerSession = $customerSession;
        $this->checkoutSession = $checkoutSession;
    }

    public function getRedirect()
    {
        $this->updateLastCustomerId();

        $result = $this->resultFactory->create(ResultFactory::TYPE_REDIRECT);

        $afterAmazonAuthUrl = $this->customerUrl->getAccountUrl();

        if ($this->checkoutSession->getQuote() && (int)$this->checkoutSession->getQuote()->getItemsCount() > 0) {
            $afterAmazonAuthUrl = $this->url->getUrl('checkout');
        } elseif ($this->customerSession->getAfterAmazonAuthUrl()) {
            $afterAmazonAuthUrl = $this->customerSession->getAfterAmazonAuthUrl();
        }

        $result->setUrl($afterAmazonAuthUrl);

        return $result;
    }
}
